#!/bin/bash
####################################################################
#####                                                          #####
#####             IRC-28C Firmware Updater                     #####
#####                                                          #####
####################################################################
###
### Revision 2.0
### 10-31-2016
### Seth Jesse
### USL, LLC
### Copyright USL, LLC 2016, all rights reserved.
###
### Revision of the original from Jay Wyatt's work of 2015.
###
###  Shell script to batch update multiple IRC-28's.
###  Place device IP Addresses into input.txt - one address per line

STR1="http://"
STR2="/protect/update.htm"
updateCnt=0
skipCnt=0
failCnt=0
breakonfail=1  # Set to 1 to exit if any IRC panel fails.
compareSTR1=$(echo -ne "    <h1>USL Caption Encoder v")
compareSTR2=$(echo -ne "</h1>\r")

# Get the file name or a "-h" for help from the arguments
if [ -z "$1" ]
  then
    echo -e "Please specify the update file."
# Help information
elif [[ $1 = "-h" ]]
  then
	echo -e "This script will take the IP addresses specified in 'input.txt' file and update each with the update file specified in the arguments."
	echo -e ""
	echo -e "Usage:  IRCupdater.sh filename"
	echo -e "  filename            Name of the update file for the IRC-28Cs "
	echo -e ""
# Check that the file exists
elif [ ! -f $1 ]
  then
    echo -e "The specified file was not found."
# Main process
else
	# Parse the update version
	NAME=${1%.hex}  
	NAME=${NAME##*/}
	NAME=${NAME##*\\}
	NAME=${NAME##*v}
	echo "Updating to version "$NAME
	compareSTR=$compareSTR1$NAME$compareSTR2
	
	while read -r line #Read each line of input.txt
	do
		result=$(curl -s $STR1$line | grep "<h1>USL Caption Encoder") #WebScrape Version

		if [[ $result != $compareSTR ]]  #If not current verion
		  then
			echo -e "\n**** Updating "$line" Allow 3-5 minutes ****"
			response=$(curl -s -F "md5file=@$1" -m 175 -u admin:ultra $STR1$line$STR2) #Curl put the update file.
			sleep 15 #Wait for device to reboot
			response=$(curl -s $STR1$line | grep "<h1>USL Caption Encoder") #Webscrape Version again
			if [[ $response = $compareSTR ]] #Check for Success
			  then
				echo -e "**** Success ****"
				updateCnt=$((updateCnt+1)) #Increment Success Counter
			  else
				echo -e "**** Failure on "$line" ****"
				failCnt=$((failCnt+1)) #Increment Fail Counter
				if [[breakonfail=1]]
				  then
					echo -e "Halting update script..."
					break #quit program
				fi
			fi
		elif [[ $result = $compareSTR ]] #Check if already Up-To-Date
		  then
			echo -e "\n**** Device "$line" Already Up-To-Date ****"
			skipCnt=$((skipCnt+1)) #Increment Up-To-Date Counter
		fi
	done < input.txt
fi

# Give Feedback
echo -e "\n"$updateCnt" unit(s) successfully updated"
echo -e $skipCnt" unit(s) were already up-to-date"
echo -e $failCnt" unit(s) failed to update"
